[pypy-commit] stmgc default: The various places that fill with 0xDD bytes should not all use the same

arigo noreply at buildbot.pypy.org
Mon Mar 3 11:55:15 CET 2014


Author: Armin Rigo <arigo at tunes.org>
Branch: 
Changeset: r937:ae9ccd94b4ea
Date: 2014-03-03 11:55 +0100
http://bitbucket.org/pypy/stmgc/changeset/ae9ccd94b4ea/

Log:	The various places that fill with 0xDD bytes should not all use the
	same pattern.

diff --git a/c7/stm/largemalloc.c b/c7/stm/largemalloc.c
--- a/c7/stm/largemalloc.c
+++ b/c7/stm/largemalloc.c
@@ -254,7 +254,7 @@
 #ifndef NDEBUG
     assert(chunk->size >= sizeof(dlist_t));
     assert(chunk->size <= (((char *)last_chunk) - (char *)data));
-    memset(data, 0xDD, chunk->size);
+    memset(data, 0xDE, chunk->size);
 #endif
 
     /* try to merge with the following chunk in memory */
diff --git a/c7/stm/setup.c b/c7/stm/setup.c
--- a/c7/stm/setup.c
+++ b/c7/stm/setup.c
@@ -36,8 +36,8 @@
            NULL accesses land.  We mprotect it so that accesses fail. */
         mprotect(segment_base, 4096, PROT_NONE);
 
-        /* Fill the TLS page (page 1) with 0xDD, for debugging */
-        memset(REAL_ADDRESS(segment_base, 4096), 0xDD, 4096);
+        /* Fill the TLS page (page 1) with 0xDC, for debugging */
+        memset(REAL_ADDRESS(segment_base, 4096), 0xDC, 4096);
         /* Make a "hole" at STM_PSEGMENT */
         memset(REAL_ADDRESS(segment_base, STM_PSEGMENT), 0,
                sizeof(*STM_PSEGMENT));


More information about the pypy-commit mailing list